=====
Hyrax
=====
--------------------------------------------------------------------------------
A low-code solution for rapid experimentation with machine learning in astronomy
--------------------------------------------------------------------------------

Hyrax is an extensible platform that handles much of the boilerplate code that
is often required for a machine learning project in astronomy.
Hyrax users are able to focus on the science work of model development and
results analysis instead of infrastructrue.


.. figure:: _static/hyrax_box.png
   :align: center
   :alt: Hyrax Design Philosophy
   :width: 80%

   Figure inspired by Sculley et al. ‘15


.. grid:: 1 1 2 2

   .. grid-item-card:: Getting Started
       :link: getting_started
       :link-type: doc

       Installation and first steps with Hyrax

   .. grid-item-card:: Science Examples
       :link: science_examples
       :link-type: doc

       Scientific machine learning with Hyrax

.. grid:: 1 1 2 2

   .. grid-item-card:: Core Concepts
       :link: core_concepts
       :link-type: doc

       Deep dives to get the most out of Hyrax

   .. grid-item-card:: API Reference
       :link: reference_and_faq
       :link-type: doc

       Detailed description of the Hyrax API


.. toctree::
   :hidden:

   Getting started <getting_started>
   Core concepts <core_concepts>
   Hyrax verbs <verbs>
   Common workflows <common_workflows>
   Science examples <science_examples>
   Scaling and Deployment <scaling_and_deployment>
   Sample Jupyter notebooks <notebooks>
   Reference and FAQ <reference_and_faq>
